% vf.m
%
% Imlements the fisher-kpp traveling wave ODE
%   dx/dt = y
%   dy/dt =-cy - u(1-u)

%
% Inputs:
%   t - Time variable: not used here because our equation
%       is independent of time, or 'autonomous'.
%   x - Independent variable: has 3 dimensions
%   p - parameters, enter in the solver file
% Output:
%   dx - First derivative: the rate of change of the three dimension
%        values over time, given the values of each dimension
function dx = duff(t, x, p)

% Standard constants for the Lorenz Attractor
d = p(1);
g = p(2);
w = p(3);
%rho = p(2);
%beta = p(3);

dx = [0;0];



dx(1) = x(2);
dx(2) =x(1) - x(1).^3 - d*x(2) + g*cos(w*t);
%dx(3) = x(1)*x(2)-beta*x(3);
